@@ -1052,7 +1052,7 @@ define([
     /**
      * Version
      */
-    Config.version = "2.4.5";
+    Config.version = "2.4.6";
 
     /**
      * Type of mode
@@ -1107,7 +1107,7 @@ define([
             /** Scaling */
             'StandardScaler', 'RobustScaler', 'MinMaxScaler', 'Normalizer', 'FunctionTransformer', 'PolynomialFeatures', 'KBinsDiscretizer',
             /** ETC */
-            'ColumnTransformer'
+            'SimpleImputer', 'ColumnTransformer'
         ],
         'Regression': [
             'LinearRegression', 'Ridge', 'Lasso', 'ElasticNet', 'SVR', 'DecisionTreeRegressor', 'RandomForestRegressor', 'GradientBoostingRegressor', 'XGBRegressor', 'LGBMRegressor', 'CatBoostRegressor',
@@ -1123,6 +1123,9 @@ define([
         ],
         'Auto ML': [
             'AutoSklearnRegressor', 'AutoSklearnClassifier', 'TPOTRegressor', 'TPOTClassifier'
+        ],
+        'ETC': [
+            'GridSearchCV'
         ]
     };
 
@@ -1132,7 +1135,8 @@ define([
         ...Config.ML_DATA_DICT['Classification'],
         ...Config.ML_DATA_DICT['Clustering'],
         ...Config.ML_DATA_DICT['Dimension Reduction'],
-        ...Config.ML_DATA_DICT['Auto ML']
+        ...Config.ML_DATA_DICT['Auto ML'],
+        ...Config.ML_DATA_DICT['ETC']
     ];
 
     return Config;
